@@ -47,9 +47,6 @@ FAILEDOPERATION_INQUIRYREFUNDPRICEFAILED = 'FailedOperation.InquiryRefundPriceFa
 # The EMR instance `ins-xxxxxxxx` does not support this operation.
 FAILEDOPERATION_INVALIDINSTANCEAPPLICATIONROLEEMR = 'FailedOperation.InvalidInstanceApplicationRoleEmr'
 
-# No available IPs in the subnet.
-FAILEDOPERATION_NOAVAILABLEIPADDRESSCOUNTINSUBNET = 'FailedOperation.NoAvailableIpAddressCountInSubnet'
-
 # This instance does not bind an EIP.
 FAILEDOPERATION_NOTFOUNDEIP = 'FailedOperation.NotFoundEIP'
 
@@ -71,27 +68,15 @@ FAILEDOPERATION_RIMAGESHAREFAILED = 'FailedOperation.RImageShareFailed'
 # Security group operation failed.
 FAILEDOPERATION_SECURITYGROUPACTIONFAILED = 'FailedOperation.SecurityGroupActionFailed'
 
-# The snapshot size is larger than the disk capacity. You need a larger disk space.
-FAILEDOPERATION_SNAPSHOTSIZELARGERTHANDATASIZE = 'FailedOperation.SnapshotSizeLargerThanDataSize'
-
-# The snapshot size should be larger than the cloud disk capacity.
-FAILEDOPERATION_SNAPSHOTSIZELESSTHANDATASIZE = 'FailedOperation.SnapshotSizeLessThanDataSize'
-
 # The tag key specified in the request is reserved for the system.
 FAILEDOPERATION_TAGKEYRESERVED = 'FailedOperation.TagKeyReserved'
 
-# This image is not a Linux&x86_64 image.
-FAILEDOPERATION_TATAGENTNOTSUPPORT = 'FailedOperation.TatAgentNotSupport'
-
 # The instance is unreturnable.
 FAILEDOPERATION_UNRETURNABLE = 'FailedOperation.Unreturnable'
 
 # The image quota has been exceeded.
 IMAGEQUOTALIMITEXCEEDED = 'ImageQuotaLimitExceeded'
 
-# You are trying to create more instances than your remaining quota allows.
-INSTANCESQUOTALIMITEXCEEDED = 'InstancesQuotaLimitExceeded'
-
 # Internal error.
 INTERNALERROR = 'InternalError'
 
@@ -209,9 +194,6 @@ INVALIDPARAMETER_DATADISKNOTBELONGSPECIFIEDINSTANCE = 'InvalidParameter.DataDisk
 # Only one system disk snapshot can be included.
 INVALIDPARAMETER_DUPLICATESYSTEMSNAPSHOTS = 'InvalidParameter.DuplicateSystemSnapshots'
 
-# This operation is not supported under the current status of the CVM.
-INVALIDPARAMETER_HOSTIDSTATUSNOTSUPPORT = 'InvalidParameter.HostIdStatusNotSupport'
-
 # The specified HostName is invalid.
 INVALIDPARAMETER_HOSTNAMEILLEGAL = 'InvalidParameter.HostNameIllegal'
 
@@ -230,9 +212,6 @@ INVALIDPARAMETER_INVALIDPARAMETERCOEXISTIMAGEIDSFILTERS = 'InvalidParameter.Inva
 # Invalid URL.
 INVALIDPARAMETER_INVALIDPARAMETERURLERROR = 'InvalidParameter.InvalidParameterUrlError'
 
-# `CoreCount` and `ThreadPerCore` must be specified at the same time.
-INVALIDPARAMETER_LACKCORECOUNTORTHREADPERCORE = 'InvalidParameter.LackCoreCountOrThreadPerCore'
-
 # Local data disks cannot be used to create instance images.
 INVALIDPARAMETER_LOCALDATADISKNOTSUPPORT = 'InvalidParameter.LocalDataDiskNotSupport'
 
@@ -269,24 +248,12 @@ INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 # The shared bandwidth package ID is invalid. Please provide a standard shared bandwidth package ID in the format similar to bwp-xxxxxxxx. In this format, the letter x stands for a lowercase character or a number.
 INVALIDPARAMETERVALUE_BANDWIDTHPACKAGEIDMALFORMED = 'InvalidParameterValue.BandwidthPackageIdMalformed'
 
-# The specified bandwidth package does not exist.
-INVALIDPARAMETERVALUE_BANDWIDTHPACKAGEIDNOTFOUND = 'InvalidParameterValue.BandwidthPackageIdNotFound'
-
-# Corresponding CHC hosts not found
-INVALIDPARAMETERVALUE_CHCHOSTSNOTFOUND = 'InvalidParameterValue.ChcHostsNotFound'
-
 # The minimum capacity of a SSD data disk is 100 GB.
 INVALIDPARAMETERVALUE_CLOUDSSDDATADISKSIZETOOSMALL = 'InvalidParameterValue.CloudSsdDataDiskSizeTooSmall'
 
-# Illegal core count.
-INVALIDPARAMETERVALUE_CORECOUNTVALUE = 'InvalidParameterValue.CoreCountValue'
-
 # Incorrect placement group ID format.
 INVALIDPARAMETERVALUE_DISASTERRECOVERGROUPIDMALFORMED = 'InvalidParameterValue.DisasterRecoverGroupIdMalformed'
 
-# Duplicate parameter value
-INVALIDPARAMETERVALUE_DUPLICATE = 'InvalidParameterValue.Duplicate'
-
 # Non-GPU instances cannot be changed to the GPU instance.
 INVALIDPARAMETERVALUE_GPUINSTANCEFAMILY = 'InvalidParameterValue.GPUInstanceFamily'
 
@@ -305,24 +272,15 @@ INVALIDPARAMETERVALUE_INSTANCETYPENOTFOUND = 'InvalidParameterValue.InstanceType
 # This type of instances cannot be added to the HPC cluster.
 INVALIDPARAMETERVALUE_INSTANCETYPENOTSUPPORTHPCCLUSTER = 'InvalidParameterValue.InstanceTypeNotSupportHpcCluster'
 
-# The HPC cluster needs to be specified for the high-performance computing instance.
-INVALIDPARAMETERVALUE_INSTANCETYPEREQUIREDHPCCLUSTER = 'InvalidParameterValue.InstanceTypeRequiredHpcCluster'
-
-# The spot instance is out of stock.
-INVALIDPARAMETERVALUE_INSUFFICIENTOFFERING = 'InvalidParameterValue.InsufficientOffering'
-
-# The bid is lower than the market price.
-INVALIDPARAMETERVALUE_INSUFFICIENTPRICE = 'InvalidParameterValue.InsufficientPrice'
-
 # Invalid AppID
 INVALIDPARAMETERVALUE_INVALIDAPPIDFORMAT = 'InvalidParameterValue.InvalidAppIdFormat'
 
+# Converting to a non-GPU or other type of GPU instance is not supported.
+INVALIDPARAMETERVALUE_INVALIDGPUFAMILYCHANGE = 'InvalidParameterValue.InvalidGPUFamilyChange'
+
 # The specified image does not support the specified instance type.
 INVALIDPARAMETERVALUE_INVALIDIMAGEFORGIVENINSTANCETYPE = 'InvalidParameterValue.InvalidImageForGivenInstanceType'
 
-# A RAW image cannot be used to create a CVM. Choose another image.
-INVALIDPARAMETERVALUE_INVALIDIMAGEFORMAT = 'InvalidParameterValue.InvalidImageFormat'
-
 # The image does not support this operation.
 INVALIDPARAMETERVALUE_INVALIDIMAGEID = 'InvalidParameterValue.InvalidImageId'
 
@@ -335,12 +293,12 @@ INVALIDPARAMETERVALUE_INVALIDIMAGEOSNAME = 'InvalidParameterValue.InvalidImageOs
 # The image has another ongoing task. Please check and try again later.
 INVALIDPARAMETERVALUE_INVALIDIMAGESTATE = 'InvalidParameterValue.InvalidImageState'
 
+# The instance configuration is upgraded for free and cannot be downgraded within 3 months.
+INVALIDPARAMETERVALUE_INVALIDINSTANCESOURCE = 'InvalidParameterValue.InvalidInstanceSource'
+
 # Invalid IP address.
 INVALIDPARAMETERVALUE_INVALIDIPFORMAT = 'InvalidParameterValue.InvalidIpFormat'
 
-# Incorrect format of instance launch template description.
-INVALIDPARAMETERVALUE_INVALIDLAUNCHTEMPLATEDESCRIPTION = 'InvalidParameterValue.InvalidLaunchTemplateDescription'
-
 # Incorrect format of instance launch template name.
 INVALIDPARAMETERVALUE_INVALIDLAUNCHTEMPLATENAME = 'InvalidParameterValue.InvalidLaunchTemplateName'
 
@@ -353,8 +311,8 @@ INVALIDPARAMETERVALUE_INVALIDPARAMETERVALUELIMIT = 'InvalidParameterValue.Invali
 # Invalid password. The specified password does not meet the complexity requirements (e.g., too long or too short)
 INVALIDPARAMETERVALUE_INVALIDPASSWORD = 'InvalidParameterValue.InvalidPassword'
 
-# Incorrect time format.
-INVALIDPARAMETERVALUE_INVALIDTIMEFORMAT = 'InvalidParameterValue.InvalidTimeFormat'
+# 
+INVALIDPARAMETERVALUE_INVALIDREGION = 'InvalidParameterValue.InvalidRegion'
 
 # Incorrect UserData format. Use the Base64-encoded format.
 INVALIDPARAMETERVALUE_INVALIDUSERDATAFORMAT = 'InvalidParameterValue.InvalidUserDataFormat'
@@ -425,15 +383,9 @@ INVALIDPARAMETERVALUE_TOOLONG = 'InvalidParameterValue.TooLong'
 # The VPC ID `xxx` is invalid. Please provide a VPC ID in the format of vpc-xxxxxxxx, where “x” can be a lowercase letter or number.
 INVALIDPARAMETERVALUE_VPCIDMALFORMED = 'InvalidParameterValue.VpcIdMalformed'
 
-# The specified VpcId doesn't exist.
-INVALIDPARAMETERVALUE_VPCIDNOTEXIST = 'InvalidParameterValue.VpcIdNotExist'
-
 # The VPC and instance must be in the same availability zone.
 INVALIDPARAMETERVALUE_VPCIDZONEIDNOTMATCH = 'InvalidParameterValue.VpcIdZoneIdNotMatch'
 
-# This VPC does not support the IPv6 addresses.
-INVALIDPARAMETERVALUE_VPCNOTSUPPORTIPV6ADDRESS = 'InvalidParameterValue.VpcNotSupportIpv6Address'
-
 # The availability zone does not support this operation.
 INVALIDPARAMETERVALUE_ZONENOTSUPPORTED = 'InvalidParameterValue.ZoneNotSupported'
 
@@ -482,18 +434,9 @@ LIMITEXCEEDED_ASSOCIATEUSGLIMITEXCEEDED = 'LimitExceeded.AssociateUSGLimitExceed
 # The CVM ENIs associated with the security group has exceeded the limit.
 LIMITEXCEEDED_CVMSVIFSPERSECGROUPLIMITEXCEEDED = 'LimitExceeded.CvmsVifsPerSecGroupLimitExceeded'
 
-# The quota of the specified placement group is insufficient.
-LIMITEXCEEDED_DISASTERRECOVERGROUP = 'LimitExceeded.DisasterRecoverGroup'
-
 # The number of ENIs on a specified instance exceeds the maximum ENIs allowed for the target instance type. Delete some ENIs and try again.
 LIMITEXCEEDED_ENINUMLIMIT = 'LimitExceeded.EniNumLimit'
 
-# Number of IPs on this ENI reached the upper limit
-LIMITEXCEEDED_IPV6ADDRESSNUM = 'LimitExceeded.IPv6AddressNum'
-
-# Reached the upper limit of the ENIs for the instance.
-LIMITEXCEEDED_INSTANCEENINUMLIMIT = 'LimitExceeded.InstanceEniNumLimit'
-
 # You are short of the instance quota.
 LIMITEXCEEDED_INSTANCEQUOTA = 'LimitExceeded.InstanceQuota'
 
@@ -506,9 +449,6 @@ LIMITEXCEEDED_LAUNCHTEMPLATEQUOTA = 'LimitExceeded.LaunchTemplateQuota'
 # The number of instance launch template versions exceeds the limit.
 LIMITEXCEEDED_LAUNCHTEMPLATEVERSIONQUOTA = 'LimitExceeded.LaunchTemplateVersionQuota'
 
-# Your quota for monthly-subscribed instances is full. Increase your quota and try again.
-LIMITEXCEEDED_PREPAYQUOTA = 'LimitExceeded.PrepayQuota'
-
 # The number of security groups exceeds the quota limit.
 LIMITEXCEEDED_SINGLEUSGQUOTA = 'LimitExceeded.SingleUSGQuota'
 
@@ -704,15 +644,18 @@ UNSUPPORTEDOPERATION_INSTANCESTATETERMINATING = 'UnsupportedOperation.InstanceSt
 # The instance is under termination protection and cannot be terminated. Disable the termination protection and try again.
 UNSUPPORTEDOPERATION_INSTANCESPROTECTED = 'UnsupportedOperation.InstancesProtected'
 
+# Adjusting the data disk is not supported.
+UNSUPPORTEDOPERATION_INVALIDDATADISK = 'UnsupportedOperation.InvalidDataDisk'
+
 # The specified disk is not supported.
 UNSUPPORTEDOPERATION_INVALIDDISK = 'UnsupportedOperation.InvalidDisk'
 
+# This operation is not supported for the instance with a termination schedule. Please cancel the scheduled termination time in the instance details page and try again.
+UNSUPPORTEDOPERATION_INVALIDINSTANCENOTSUPPORTEDPROTECTEDINSTANCE = 'UnsupportedOperation.InvalidInstanceNotSupportedProtectedInstance'
+
 # The current operation is only supported for Tencent Cloud International users.
 UNSUPPORTEDOPERATION_INVALIDPERMISSIONNONINTERNATIONALACCOUNT = 'UnsupportedOperation.InvalidPermissionNonInternationalAccount'
 
-# Encrypted disks are not available in the selected regions.
-UNSUPPORTEDOPERATION_INVALIDREGIONDISKENCRYPT = 'UnsupportedOperation.InvalidRegionDiskEncrypt'
-
 # Key-pair login is not available to Windows instances.
 UNSUPPORTEDOPERATION_KEYPAIRUNSUPPORTEDWINDOWS = 'UnsupportedOperation.KeyPairUnsupportedWindows'
 
@@ -728,9 +671,6 @@ UNSUPPORTEDOPERATION_MODIFYVPCWITHCLB = 'UnsupportedOperation.ModifyVPCWithCLB'
 # This instance type does not support spot instances.
 UNSUPPORTEDOPERATION_NOINSTANCETYPESUPPORTSPOT = 'UnsupportedOperation.NoInstanceTypeSupportSpot'
 
-# Failed to configure the scheduled action for the current instance. 
-UNSUPPORTEDOPERATION_NOTSUPPORTIMPORTINSTANCESACTIONTIMER = 'UnsupportedOperation.NotSupportImportInstancesActionTimer'
-
 # The instance does not support this operation.
 UNSUPPORTEDOPERATION_NOTSUPPORTINSTANCEIMAGE = 'UnsupportedOperation.NotSupportInstanceImage'
 
@@ -767,9 +707,6 @@ UNSUPPORTEDOPERATION_UNSUPPORTEDCHANGEINSTANCEFAMILYTOSA3 = 'UnsupportedOperatio
 # Changing to this model type for this instance is not allowed.
 UNSUPPORTEDOPERATION_UNSUPPORTEDCHANGEINSTANCETOTHISINSTANCEFAMILY = 'UnsupportedOperation.UnsupportedChangeInstanceToThisInstanceFamily'
 
-# A Tencent Cloud International account does not support this operation.
-UNSUPPORTEDOPERATION_UNSUPPORTEDINTERNATIONALUSER = 'UnsupportedOperation.UnsupportedInternationalUser'
-
 # The quota of user limit operations is insufficient.
 UNSUPPORTEDOPERATION_USERLIMITOPERATIONEXCEEDQUOTA = 'UnsupportedOperation.UserLimitOperationExceedQuota'
 
