@@ -36,7 +36,8 @@ class EsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateInstance", params)
+            headers = request.headers
+            body = self.call("CreateInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateInstanceResponse()
@@ -64,7 +65,8 @@ class EsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteInstance", params)
+            headers = request.headers
+            body = self.call("DeleteInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteInstanceResponse()
@@ -92,7 +94,8 @@ class EsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeInstanceLogs", params)
+            headers = request.headers
+            body = self.call("DescribeInstanceLogs", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeInstanceLogsResponse()
@@ -120,7 +123,8 @@ class EsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeInstanceOperations", params)
+            headers = request.headers
+            body = self.call("DescribeInstanceOperations", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeInstanceOperationsResponse()
@@ -148,7 +152,8 @@ class EsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeInstances", params)
+            headers = request.headers
+            body = self.call("DescribeInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeInstancesResponse()
@@ -176,7 +181,8 @@ class EsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeViews", params)
+            headers = request.headers
+            body = self.call("DescribeViews", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeViewsResponse()
@@ -204,7 +210,8 @@ class EsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetRequestTargetNodeTypes", params)
+            headers = request.headers
+            body = self.call("GetRequestTargetNodeTypes", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetRequestTargetNodeTypesResponse()
@@ -232,7 +239,8 @@ class EsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("RestartInstance", params)
+            headers = request.headers
+            body = self.call("RestartInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.RestartInstanceResponse()
@@ -260,7 +268,8 @@ class EsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("RestartKibana", params)
+            headers = request.headers
+            body = self.call("RestartKibana", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.RestartKibanaResponse()
@@ -288,7 +297,8 @@ class EsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("RestartNodes", params)
+            headers = request.headers
+            body = self.call("RestartNodes", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.RestartNodesResponse()
@@ -316,7 +326,8 @@ class EsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpdateDictionaries", params)
+            headers = request.headers
+            body = self.call("UpdateDictionaries", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UpdateDictionariesResponse()
@@ -351,7 +362,8 @@ class EsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpdateInstance", params)
+            headers = request.headers
+            body = self.call("UpdateInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UpdateInstanceResponse()
@@ -379,7 +391,8 @@ class EsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpdatePlugins", params)
+            headers = request.headers
+            body = self.call("UpdatePlugins", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UpdatePluginsResponse()
@@ -407,7 +420,8 @@ class EsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpdateRequestTargetNodeTypes", params)
+            headers = request.headers
+            body = self.call("UpdateRequestTargetNodeTypes", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UpdateRequestTargetNodeTypesResponse()
@@ -435,7 +449,8 @@ class EsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpgradeInstance", params)
+            headers = request.headers
+            body = self.call("UpgradeInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UpgradeInstanceResponse()
@@ -463,7 +478,8 @@ class EsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpgradeLicense", params)
+            headers = request.headers
+            body = self.call("UpgradeLicense", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UpgradeLicenseResponse()
