@@ -36,7 +36,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("AcquireClusterAdminRole", params)
+            headers = request.headers
+            body = self.call("AcquireClusterAdminRole", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.AcquireClusterAdminRoleResponse()
@@ -64,7 +65,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("AddExistedInstances", params)
+            headers = request.headers
+            body = self.call("AddExistedInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.AddExistedInstancesResponse()
@@ -92,7 +94,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("AddNodeToNodePool", params)
+            headers = request.headers
+            body = self.call("AddNodeToNodePool", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.AddNodeToNodePoolResponse()
@@ -120,7 +123,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("AddVpcCniSubnets", params)
+            headers = request.headers
+            body = self.call("AddVpcCniSubnets", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.AddVpcCniSubnetsResponse()
@@ -148,7 +152,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CheckInstancesUpgradeAble", params)
+            headers = request.headers
+            body = self.call("CheckInstancesUpgradeAble", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CheckInstancesUpgradeAbleResponse()
@@ -176,7 +181,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateCluster", params)
+            headers = request.headers
+            body = self.call("CreateCluster", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateClusterResponse()
@@ -204,7 +210,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateClusterAsGroup", params)
+            headers = request.headers
+            body = self.call("CreateClusterAsGroup", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateClusterAsGroupResponse()
@@ -232,7 +239,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateClusterEndpoint", params)
+            headers = request.headers
+            body = self.call("CreateClusterEndpoint", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateClusterEndpointResponse()
@@ -260,7 +268,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateClusterEndpointVip", params)
+            headers = request.headers
+            body = self.call("CreateClusterEndpointVip", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateClusterEndpointVipResponse()
@@ -288,7 +297,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateClusterInstances", params)
+            headers = request.headers
+            body = self.call("CreateClusterInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateClusterInstancesResponse()
@@ -316,7 +326,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateClusterNodePool", params)
+            headers = request.headers
+            body = self.call("CreateClusterNodePool", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateClusterNodePoolResponse()
@@ -344,7 +355,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateClusterNodePoolFromExistingAsg", params)
+            headers = request.headers
+            body = self.call("CreateClusterNodePoolFromExistingAsg", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateClusterNodePoolFromExistingAsgResponse()
@@ -372,7 +384,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateClusterRouteTable", params)
+            headers = request.headers
+            body = self.call("CreateClusterRouteTable", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateClusterRouteTableResponse()
@@ -400,7 +413,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreatePrometheusAlertRule", params)
+            headers = request.headers
+            body = self.call("CreatePrometheusAlertRule", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreatePrometheusAlertRuleResponse()
@@ -428,7 +442,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteCluster", params)
+            headers = request.headers
+            body = self.call("DeleteCluster", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteClusterResponse()
@@ -456,7 +471,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteClusterAsGroups", params)
+            headers = request.headers
+            body = self.call("DeleteClusterAsGroups", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteClusterAsGroupsResponse()
@@ -484,7 +500,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteClusterEndpoint", params)
+            headers = request.headers
+            body = self.call("DeleteClusterEndpoint", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteClusterEndpointResponse()
@@ -512,7 +529,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteClusterEndpointVip", params)
+            headers = request.headers
+            body = self.call("DeleteClusterEndpointVip", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteClusterEndpointVipResponse()
@@ -540,7 +558,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteClusterInstances", params)
+            headers = request.headers
+            body = self.call("DeleteClusterInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteClusterInstancesResponse()
@@ -568,7 +587,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteClusterNodePool", params)
+            headers = request.headers
+            body = self.call("DeleteClusterNodePool", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteClusterNodePoolResponse()
@@ -596,7 +616,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteClusterRoute", params)
+            headers = request.headers
+            body = self.call("DeleteClusterRoute", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteClusterRouteResponse()
@@ -624,7 +645,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteClusterRouteTable", params)
+            headers = request.headers
+            body = self.call("DeleteClusterRouteTable", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteClusterRouteTableResponse()
@@ -652,7 +674,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeletePrometheusAlertRule", params)
+            headers = request.headers
+            body = self.call("DeletePrometheusAlertRule", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeletePrometheusAlertRuleResponse()
@@ -680,7 +703,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAvailableClusterVersion", params)
+            headers = request.headers
+            body = self.call("DescribeAvailableClusterVersion", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeAvailableClusterVersionResponse()
@@ -708,7 +732,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeClusterAsGroupOption", params)
+            headers = request.headers
+            body = self.call("DescribeClusterAsGroupOption", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeClusterAsGroupOptionResponse()
@@ -736,7 +761,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeClusterAsGroups", params)
+            headers = request.headers
+            body = self.call("DescribeClusterAsGroups", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeClusterAsGroupsResponse()
@@ -764,7 +790,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeClusterAuthenticationOptions", params)
+            headers = request.headers
+            body = self.call("DescribeClusterAuthenticationOptions", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeClusterAuthenticationOptionsResponse()
@@ -792,7 +819,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeClusterCommonNames", params)
+            headers = request.headers
+            body = self.call("DescribeClusterCommonNames", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeClusterCommonNamesResponse()
@@ -820,7 +848,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeClusterEndpointStatus", params)
+            headers = request.headers
+            body = self.call("DescribeClusterEndpointStatus", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeClusterEndpointStatusResponse()
@@ -848,7 +877,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeClusterEndpointVipStatus", params)
+            headers = request.headers
+            body = self.call("DescribeClusterEndpointVipStatus", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeClusterEndpointVipStatusResponse()
@@ -876,7 +906,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeClusterInstances", params)
+            headers = request.headers
+            body = self.call("DescribeClusterInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeClusterInstancesResponse()
@@ -904,7 +935,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeClusterKubeconfig", params)
+            headers = request.headers
+            body = self.call("DescribeClusterKubeconfig", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeClusterKubeconfigResponse()
@@ -932,7 +964,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeClusterNodePoolDetail", params)
+            headers = request.headers
+            body = self.call("DescribeClusterNodePoolDetail", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeClusterNodePoolDetailResponse()
@@ -960,7 +993,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeClusterNodePools", params)
+            headers = request.headers
+            body = self.call("DescribeClusterNodePools", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeClusterNodePoolsResponse()
@@ -988,7 +1022,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeClusterRouteTables", params)
+            headers = request.headers
+            body = self.call("DescribeClusterRouteTables", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeClusterRouteTablesResponse()
@@ -1016,7 +1051,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeClusterRoutes", params)
+            headers = request.headers
+            body = self.call("DescribeClusterRoutes", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeClusterRoutesResponse()
@@ -1044,7 +1080,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeClusterSecurity", params)
+            headers = request.headers
+            body = self.call("DescribeClusterSecurity", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeClusterSecurityResponse()
@@ -1072,7 +1109,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeClusterStatus", params)
+            headers = request.headers
+            body = self.call("DescribeClusterStatus", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeClusterStatusResponse()
@@ -1100,7 +1138,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeClusters", params)
+            headers = request.headers
+            body = self.call("DescribeClusters", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeClustersResponse()
@@ -1128,7 +1167,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeEnableVpcCniProgress", params)
+            headers = request.headers
+            body = self.call("DescribeEnableVpcCniProgress", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeEnableVpcCniProgressResponse()
@@ -1156,7 +1196,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeExistedInstances", params)
+            headers = request.headers
+            body = self.call("DescribeExistedInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeExistedInstancesResponse()
@@ -1184,7 +1225,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeImages", params)
+            headers = request.headers
+            body = self.call("DescribeImages", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeImagesResponse()
@@ -1212,7 +1254,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribePrometheusInstance", params)
+            headers = request.headers
+            body = self.call("DescribePrometheusInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribePrometheusInstanceResponse()
@@ -1240,7 +1283,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeRegions", params)
+            headers = request.headers
+            body = self.call("DescribeRegions", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeRegionsResponse()
@@ -1268,7 +1312,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeRouteTableConflicts", params)
+            headers = request.headers
+            body = self.call("DescribeRouteTableConflicts", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeRouteTableConflictsResponse()
@@ -1296,7 +1341,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeTKEEdgeScript", params)
+            headers = request.headers
+            body = self.call("DescribeTKEEdgeScript", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeTKEEdgeScriptResponse()
@@ -1324,7 +1370,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeVersions", params)
+            headers = request.headers
+            body = self.call("DescribeVersions", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeVersionsResponse()
@@ -1352,7 +1399,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeVpcCniPodLimits", params)
+            headers = request.headers
+            body = self.call("DescribeVpcCniPodLimits", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeVpcCniPodLimitsResponse()
@@ -1380,7 +1428,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DisableClusterDeletionProtection", params)
+            headers = request.headers
+            body = self.call("DisableClusterDeletionProtection", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DisableClusterDeletionProtectionResponse()
@@ -1408,7 +1457,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("EnableClusterDeletionProtection", params)
+            headers = request.headers
+            body = self.call("EnableClusterDeletionProtection", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.EnableClusterDeletionProtectionResponse()
@@ -1436,7 +1486,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("EnableVpcCniNetworkType", params)
+            headers = request.headers
+            body = self.call("EnableVpcCniNetworkType", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.EnableVpcCniNetworkTypeResponse()
@@ -1464,7 +1515,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetUpgradeInstanceProgress", params)
+            headers = request.headers
+            body = self.call("GetUpgradeInstanceProgress", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetUpgradeInstanceProgressResponse()
@@ -1492,7 +1544,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyClusterAsGroupAttribute", params)
+            headers = request.headers
+            body = self.call("ModifyClusterAsGroupAttribute", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyClusterAsGroupAttributeResponse()
@@ -1520,7 +1573,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyClusterAsGroupOptionAttribute", params)
+            headers = request.headers
+            body = self.call("ModifyClusterAsGroupOptionAttribute", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyClusterAsGroupOptionAttributeResponse()
@@ -1548,7 +1602,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyClusterAttribute", params)
+            headers = request.headers
+            body = self.call("ModifyClusterAttribute", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyClusterAttributeResponse()
@@ -1576,7 +1631,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyClusterAuthenticationOptions", params)
+            headers = request.headers
+            body = self.call("ModifyClusterAuthenticationOptions", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyClusterAuthenticationOptionsResponse()
@@ -1604,7 +1660,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyClusterEndpointSP", params)
+            headers = request.headers
+            body = self.call("ModifyClusterEndpointSP", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyClusterEndpointSPResponse()
@@ -1632,7 +1689,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyClusterNodePool", params)
+            headers = request.headers
+            body = self.call("ModifyClusterNodePool", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyClusterNodePoolResponse()
@@ -1660,7 +1718,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyNodePoolInstanceTypes", params)
+            headers = request.headers
+            body = self.call("ModifyNodePoolInstanceTypes", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyNodePoolInstanceTypesResponse()
@@ -1688,7 +1747,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyPrometheusAlertRule", params)
+            headers = request.headers
+            body = self.call("ModifyPrometheusAlertRule", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyPrometheusAlertRuleResponse()
@@ -1716,7 +1776,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("RemoveNodeFromNodePool", params)
+            headers = request.headers
+            body = self.call("RemoveNodeFromNodePool", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.RemoveNodeFromNodePoolResponse()
@@ -1744,7 +1805,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SetNodePoolNodeProtection", params)
+            headers = request.headers
+            body = self.call("SetNodePoolNodeProtection", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SetNodePoolNodeProtectionResponse()
@@ -1772,7 +1834,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpdateClusterVersion", params)
+            headers = request.headers
+            body = self.call("UpdateClusterVersion", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UpdateClusterVersionResponse()
@@ -1800,7 +1863,8 @@ class TkeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpgradeClusterInstances", params)
+            headers = request.headers
+            body = self.call("UpgradeClusterInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UpgradeClusterInstancesResponse()
